% EE2 - PERSONALITY v3, 2016-08-23

clear all
clc

global B_backup; % this one is for storing B in case iterations are interrupted with ctrl-c


%% ****************************  loading data  ****************************


EstimOpt.DataFile = ('EE2_data_01.mat');
DATA = load(EstimOpt.DataFile);


%% ****************************  data transformations  ****************************


DATA.SQ = DATA.ALT == 3;

% unique(DATA.FOIL) % frequency of large-scale spills
DATA.FLS0 = DATA.FOIL == 0; % very often, 1/2 years - baseline
DATA.FLS1 = DATA.FOIL == 1; % often, 1/10 years
DATA.FLS2 = DATA.FOIL == 2; % sometimes, 1/150 years
DATA.FLS3 = DATA.FOIL == 3; % rarely, 1/300 years - GES

DATA.FLS = 1/2*ones(size(DATA.FOIL));
DATA.FLS(DATA.FOIL == 1) = 1/10;
DATA.FLS(DATA.FOIL == 2) = 1/150;
DATA.FLS(DATA.FOIL == 3) = 1/300;
DATA.FLS = 0.5 - DATA.FLS;

% unique(DATA.POIL) % probability of reaching the shore
DATA.PRS0 = DATA.POIL == 0; % very high, 99% - baseline
DATA.PRS1 = DATA.POIL == 1; % high, 75%
DATA.PRS2 = DATA.POIL == 2; % average, 50%
DATA.PRS3 = DATA.POIL == 3; % low, 25% - GES

DATA.PRS = 0.99*ones(size(DATA.POIL));
DATA.PRS(DATA.POIL == 1) = 0.75;
DATA.PRS(DATA.POIL == 2) = 0.50;
DATA.PRS(DATA.POIL == 3) = 0.25;
DATA.PRS = 0.99 - DATA.PRS;

% unique(DATA.WQ) % water quality
DATA.WQ0 = DATA.WQ == 0; % poor - baseline
DATA.WQ1 = DATA.WQ == 1; % moderate
DATA.WQ2 = DATA.WQ == 2; % good - GES

% unique(DATA.IS) % new non-indigenous species
DATA.IS0 = DATA.IS == 0; % often, 1/1.5 years - baseline
DATA.IS1 = DATA.IS == 1; % rarely, 1/15-20
DATA.IS2 = DATA.IS == 2; % in exceptional cases, 1/50 - GES

DATA.ISc = ones(size(DATA.POIL)) / 1.5;
DATA.ISc(DATA.IS == 1) = 1 / 17.5;
DATA.ISc(DATA.IS == 2) = 1 / 50;
DATA.ISc = 1/1.5 - DATA.ISc;


DATA.protest = (DATA.q18 == 2 & (DATA.q19 == 3 | DATA.q19 == 6));

DATA.Extraversion = DATA.q37_1 + (-DATA.q37_6+8);
DATA.Extraversion = (DATA.Extraversion - mean(DATA.Extraversion))./std(DATA.Extraversion);
DATA.Agreeableness = DATA.q37_7 + (-DATA.q37_2+8);
DATA.Agreeableness = (DATA.Agreeableness - mean(DATA.Agreeableness))./std(DATA.Agreeableness);
DATA.Conscientiousness = DATA.q37_3 + (-DATA.q37_8+8);
DATA.Conscientiousness = (DATA.Conscientiousness - mean(DATA.Conscientiousness))./std(DATA.Conscientiousness);
DATA.Neuroticism = DATA.q37_4 + (-DATA.q37_9+8);
DATA.Neuroticism = (DATA.Neuroticism - mean(DATA.Neuroticism))./std(DATA.Neuroticism);
DATA.OpennessToExperiences = DATA.q37_5 + (-DATA.q37_10+8);
DATA.OpennessToExperiences = (DATA.OpennessToExperiences - mean(DATA.OpennessToExperiences))./std(DATA.OpennessToExperiences);


%% ****************************  model specification  ****************************


DATA.X = [DATA.SQ, DATA.FLS1, DATA.FLS2, DATA.FLS3, DATA.PRS1, DATA.PRS2, DATA.PRS3, DATA.WQ1, DATA.WQ2, DATA.IS1, DATA.IS2, -DATA.C/100];
EstimOpt.NamesA = {'Status quo';'FLS 1';'FLS 2';'FLS 3';'PRS 1';'PRS 2';'PRS 3';'WQ 1';'WQ 2';'IS 1';'IS 2';'Cost'};

DATA.X = [DATA.SQ, DATA.FLS, DATA.PRS, DATA.WQ, DATA.ISc, -DATA.C/100];
EstimOpt.NamesA = {'Status quo';'FLS reduction';'PRS reduction';'WQ improvement';'IS improvement';'Cost'};


DATA.Xmea = [DATA.q37_1, DATA.q37_6, DATA.q37_7, DATA.q37_2, DATA.q37_3, DATA.q37_8, DATA.q37_4, DATA.q37_9, DATA.q37_5, DATA.q37_10];
EstimOpt.NamesMea = {'Q1', 'Q6', 'Q7', 'Q2', 'Q3', 'Q8', 'Q4', 'Q9', 'Q5', 'Q10'};

EstimOpt.NamesLV = {'Extraversion', 'Agreeableness', 'Conscientiousness','Neuroticism','Openness to Experiences'};

DATA.Y = DATA.ANS;


%% ****************************  specifying input ****************************


INPUT.Y = DATA.Y(DATA.protest == 0);
INPUT.Xa = DATA.X(DATA.protest == 0,:);

INPUT.Xmea = DATA.Xmea(DATA.protest == 0,:);


%% ****************************  sample characteristics ****************************


EstimOpt.NCT = 12; % Number of choice tasks per person
EstimOpt.NAlt = 3; % Number of alternatives
EstimOpt.NP = length(INPUT.Y)/EstimOpt.NCT/EstimOpt.NAlt;

%% **************************** estimation and optimization options ****************************


% EstimOpt.eps = 1.e-9; % overall precision level

[INPUT, Results, EstimOpt, OptimOpt] = DataCleanDCE(INPUT,EstimOpt);

EstimOpt.NRep = 1e4; % number of draws for numerical simulation
% OptimOpt.MaxIter = 1e3; % maximum number of iterations

% OptimOpt.Algorithm = 'trust-region'; %'quasi-newton'
EstimOpt.NumGrad = 1; % 1
OptimOpt.GradObj = 'off'; % 'off'
% OptimOpt.FinDiffType = 'central'; % 'forward'
% OptimOpt.Hessian = 'user-supplied'; % 'off'
% EstimOpt.HessEstFix = 1 ; % 0 = use optimization Hessian, 1 = use jacobian-based (BHHH) Hessian, 2 - use high-precision jacobian-based (BHHH) Hessian 3 - use numerical Hessian


try
    
	EstimOpt.ProjectName = '6c_2';

    
    
    %% ****************************     MNL     ****************************
    

    Results.MNL = MNL(INPUT,Results,EstimOpt,OptimOpt);
      
    
    %% ****************************     MXL     ****************************
    
    EstimOpt.Dist = [1 0 0 0 0 0 1];
  
%     Results.MXL_d.bhat = [-3.74727371866759;0.465489602863334;0.756870535622584;0.786706711144135;0.347410596580774;0.613338915719906;0.742737785654571;0.564312725206930;0.624654610727346;0.327351681702941;0.406277871423647;5.36690276672326;7.19734877516411;-0.402414294328636;0.162576414112366;-0.374027761069757;-0.0364731995986408;-0.127464098184148;0.564987663252506;-0.285291059178976;0.452972026868649;-0.238744942899841;-0.157410655987422;10.4407334457965];

% linear:
Results.MXL_d.bhat = [-4.04664464516409;1.60280162050758;1.04354231160015;0.343120942974228;0.658941015735954;5.71889511664964;7.11888127353428;1.51802982207575;1.34684179966190;0.415744707796565;-0.802304270984703;10.7938780848699];
    

    
    %% ****************************     HMNL     ****************************
    
    % EstimOpt.Dist = [0 0 0 0 0 0 0 0 0 0 0 1];
    % EstimOpt.MNLDist = EstimOpt.Dist;

    EstimOpt.Dist = [0 0 0 0 0 1];
    EstimOpt.MNLDist = EstimOpt.Dist;
    
%     EstimOpt.RealMin = 1;
    % EstimOpt.HessEstFix = 0;
    
    EstimOpt.NLatent = 5;
    EstimOpt.MeaMatrix = [ 1 1 0 0 0 0 0 0 0 0; ...
        0 0 1 1 0 0 0 0 0 0; ...
        0 0 0 0 1 1 0 0 0 0; ...
        0 0 0 0 0 0 1 1 0 0; ...
        0 0 0 0 0 0 0 0 1 1];
    EstimOpt.MeaSpecMatrix = 2;
    
%     Results.HMNL = HMNL(INPUT,Results,EstimOpt,OptimOpt);        
    

    %% ****************************     HMXL     ****************************
    
   
    B_backup = [-4.06203755192020;1.59935000197210;1.12779223836347;0.368926657183951;0.692437674578875;0.151473845147314;3.67509510766861;1.39129547558600;1.27764457594406;-0.380740656192955;0.739019669391127;4.26002973740554;0;0;0;0;0;0;0;0;0;0;0;0;0;0;0;0;0;0;0;0;0;0;0;0;0;0;0;0;0;0;0.445032710101993;-1.76802656571983;-0.577534288401128;-0.362027459497287;-0.412449542204134;0.125962908363851;-0.0435812769146002;-0.459653025979629;-1.49339578403285;-0.351245733210374;-0.407931667646825;-0.341513406560560;-0.318621962047102;-0.0666683525220617;0.101917738614081;-2.45684617761253;-1.04377821945071;-0.404794898070608;-0.318354589432800;0.0122202373235183;-0.0771194491291561;-0.118044103498328;-1.49291458465850;-0.468736273733534;-0.793502006293495;-0.734322253586154;-0.0173345394776624;-0.151513379097146;0.691216885964093;-2.56256537002848;-1.08730682901247;-0.396660835305414;-0.607861827674138;0.295580433268418;0.207270690043097;-1.03327452480481;-1.21211855184579;0.205578996921372;0.00903181232336392;0.120455476690491;-0.536936353199226;-0.806442275125228;2.18249894538872;-3.47538593408480;0.677978805698324;0.551673090545127;0.438802755938523;0.551146063881044;0.492809554975945;-0.404660950425332;-1.93682850151600;-0.617562617595273;-0.724733754315695;-0.349858056135554;0.0431443905081518;0.0433237394025886;0.513774126193925;-2.32170533982869;-0.834864610703808;-0.503547962416032;-0.423069312824508;0.178557058602402;0.0825539697659580;-0.468816623924769;-1.42563830162685;-0.350307447372105;-0.341731112072242;-0.116134188329441;-0.159646228648886;-0.583165587563265];
    B_tmp = reshape(B_backup(6*2+1:6*7),[6,5]);
    B_tmp(2:5,:) = 0;
    B_backup = [B_backup(1:6*2);B_tmp(:);B_backup(6*7+1:end)];
    EstimOpt.BActive = B_backup ~= 0;

% (qn): -13351.4619
B_backup = [-4.30856659773918;1.58104000133251;1.12762224389907;0.362878049212942;0.689860496981000;-0.143088424955550;3.83273307175242;1.37977569659533;1.29062565887390;-0.369720606872313;0.718998284848363;5.09083287284151;-0.624241127862164;0;0;0;0;0.310806761358453;0.412913767764006;0;0;0;0;0.567425270527076;0.0530825788742706;0;0;0;0;0.356689085239780;0.208646898010620;0;0;0;0;0.0397155262961771;-0.660053997685446;0;0;0;0;-0.227906900925776;0.404949812645610;-1.74305244366029;-0.590839397735192;-0.377244389255821;-0.426475681677704;0.112532850917476;-0.0601348344225062;-0.476721376726263;-1.50309104003778;-0.347912304336457;-0.400605802062474;-0.332618886248233;-0.310663230354308;-0.0574426430529225;0.257980436346965;-2.52741881190462;-0.995023853641277;-0.383288976696361;-0.295024450144046;0.0382806127900990;-0.0484277819194901;-0.216763158490030;-1.52276662595232;-0.445071517619686;-0.773151707695896;-0.716233717808073;-0.00388840062237765;-0.144801699305446;0.822140674310633;-2.72638449097170;-1.01503382148920;-0.334034166745133;-0.549020366784594;0.356839732289031;0.269930324817735;-0.859487027462210;-1.11531640314693;0.123275998073556;-0.0811851670044076;0.0293179864039345;-0.634579786378192;-0.877279908787448;4.98212211415082;-7.25819210456993;1.42429215507035;1.30885296464959;1.19452048252237;1.28151858524225;1.21072601556952;-0.372915463021595;-1.92567967366920;-0.624233497621643;-0.734538523288496;-0.361138072255318;0.0330740874451399;0.0331317265181673;0.629104621416776;-2.44181592106557;-0.776461721873917;-0.454776044150111;-0.373463714960551;0.228834721927712;0.132459601501739;-0.393346950012224;-1.39117018604976;-0.375019524784022;-0.369311440640745;-0.142955787024737;-0.187296329043305;-0.599734305943631];

% save results_EE2_6c_tr

B_backup = [-3.70903367971194;1.58985582754577;1.11906617031115;0.366262685677855;0.688557368994975;-0.350497161568217;2.94807421541181;1.39400336064653;1.25342824872662;-0.389059193941104;0.598516077903151;4.95709909235749;-0.624241127862164;0;0;0;0;0.310806761358453;0.412913767764006;0;0;0;0;0.567425270527076;0.0530825788742706;0;0;0;0;0.356689085239780;0.208646898010620;0;0;0;0;0.0397155262961771;-0.660053997685446;0;0;0;0;-0.227906900925776;0.279258153323749;-1.67666914387192;-0.630915744886255;-0.413284031300739;-0.463541929936226;0.0724645374996022;-0.0994352717867873;-0.918022831227564;-1.84077911075054;-0.146777123712609;-0.197666508039485;-0.133262972045598;-0.116647149241482;0.145015220112824;-0.0347839650811148;-2.44919660900926;-1.04166998648255;-0.407858028085963;-0.322036344213576;0.00742873480648451;-0.0824901503586565;-0.337232264480425;-1.56913176156905;-0.420047898360609;-0.743707495919017;-0.686937054435428;0.0272513440839568;-0.108833049309327;0.566693294907295;-2.42176544115894;-1.12922553620227;-0.447558809422664;-0.661502247552678;0.241538403062320;0.158077770825126;-1.49371785162933;-1.55583401366291;0.437289679022251;0.235081766705278;0.350928899195636;-0.307638092860411;-0.544840890600085;1.31754369926255;-2.37826517867107;0.311372846193181;0.179201972036988;0.0709959103290067;0.198564045971496;0.103863754989676;-0.458005441384698;-1.98967345303969;-0.591729303090213;-0.700020265136718;-0.328580957137189;0.0623164207347977;0.0605391153464666;0.502352245223833;-2.30782120762276;-0.855813955104852;-0.508690146094944;-0.420545083584491;0.178517485718295;0.0750225648007373;-0.455888140583592;-1.42299980600756;-0.349982249904142;-0.345835479921168;-0.123454175672444;-0.166192023474615;-0.585921882051429];

EstimOpt.RealMin = 1;

Results.HMXL_d = HMXL(INPUT,Results,EstimOpt,OptimOpt);        
    
    sendmail('mik@czaj.org','MATLAB: D2 - done!');
    
catch theErrorInfo
    
    sendmail('mik@czaj.org','MATLAB: D2 - error!',theErrorInfo.message);
    
end
