
% LAT - PERSONALITY v3, 2016-08-23

clear all
clc

global B_backup; % this one is for storing B in case iterations are interrupted with ctrl-c


%% ****************************  loading data  ****************************


EstimOpt.DataFile = ('LAT_data_02.mat');
DATA = load(EstimOpt.DataFile);
load('IndComplete.mat');


%% ****************************  data transformations  ****************************


DATA.SQ = DATA.ALT == 3;

% unique(DATA.RS) % reduced no. of native species
DATA.RS0 = DATA.RS == 0; % baseline, no change
DATA.RS1 = DATA.RS == 1; % minor improvement
DATA.RS2 = DATA.RS == 2; % major improvement

% unique(DATA.WQ) % water quality
DATA.WQ0 = DATA.WQ == 0; % baseline, no change
DATA.WQ1 = DATA.WQ == 1; % minor improvement
DATA.WQ2 = DATA.WQ == 2; % major improvement

% unique(DATA.IS) % invasive species
DATA.IS0 = DATA.IS == 0; % baseline, no change
DATA.IS1 = DATA.IS == 1; % minor improvement
DATA.IS2 = DATA.IS == 2; % major improvement

% unique(DATA.COST) % cost: 0,2,5,10

unique(DATA.Q4001(~isnan(DATA.Q4001)));

% dstats(DATA.Q49_region,1)

% /Q46 1 'Primary school or incomplete compulsory education (up to 8  9 classes)' 2 'Compulsory education (8  9 classes)' 3 'General secondary education (completed high school, gymnasium)'  4 'Vocational secondary education (completed vocational school, technical college)'  5 'Higher education (obtained highest academic or professional education (bachelor)), including completed college, master studies, doctoral studies'
% /Q47 1 'Employed full-time' 2 'Employed part-time' 3 'Retired' 4 'Student' 5 'Home-employed/Homemaker' 6 'Self-employed' 7 'Unemployed'
% /Q48 1 'Yes, in the last 7 days' 2 'Yes, in the last month but not in the last 7 days' 3 'Yes, more than a month ago' 4 'No, I dont use internet' 
% /Q49 1 R?ga 2 Pier?ga 3 Vidzeme 4 Kurzeme 5 Zemgale 6 Latgale
% /Q51 1 'Less than 50 LVL' 2 '51 - 100 LVL' 3 '101  150 LVL' 4 '151 - 200 LVL' 5 '201 - 250 LVL' 6 '251 - 300 LVL' 7 '301 - 350 LVL' 8 '351 - 400 LVL' 9 '401 - 500 LVL' 10 'More than 500 LVL'  11 'Respondent didnt want to state the income'.
DATA.inc(DATA.Q51 == 1) = 50;
DATA.inc(DATA.Q51 == 2) = 75;
DATA.inc(DATA.Q51 == 3) = 125;
DATA.inc(DATA.Q51 == 4) = 175;
DATA.inc(DATA.Q51 == 5) = 225;
DATA.inc(DATA.Q51 == 6) = 275;
DATA.inc(DATA.Q51 == 7) = 325;
DATA.inc(DATA.Q51 == 8) = 475;
DATA.inc(DATA.Q51 == 9) = 450;
DATA.inc(DATA.Q51 == 10) = 500;
DATA.inc = DATA.inc'*1.5/100;
DATA.inc_nan = DATA.Q51 == 11;

% DATA.Q23: Q23 'Would you personally be willing to pay anything to improve the Latvian marine environment quality concerning the described problems?'
% 1 'Yes' 2 'No' 3 'Not sure / Hard to say'


%% ****************************  model specification  ****************************

DATA.Y = DATA.CHOICE;
% recode all choices of those who are not willing to pay to SQ. 
DATA.Y(DATA.SQ == 1 & DATA.Q23 == 2) = 1;
DATA.Y(DATA.SQ ~= 1 & DATA.Q23 == 2) = 0;

% DATA.X = [DATA.SQ, DATA.RS1, DATA.RS2, DATA.WQ1, DATA.WQ2, DATA.IS1, DATA.IS2, -DATA.COST];
% EstimOpt.NamesA = {'Status quo';'RS 1';'RS 2';'WQ 1';'WQ 2';'IS 1';'IS 2';'Cost'};

DATA.X = [DATA.SQ, DATA.RS, DATA.WQ, DATA.IS, -DATA.COST];
EstimOpt.NamesA = {'Status quo';'Reduced no. of native species';'Water quality';'Invasive species';'Cost'};

DATA.Xmea = [DATA.Q4001, DATA.Q4006, DATA.Q4007, DATA.Q4002, DATA.Q4003, DATA.Q4008, DATA.Q4004, DATA.Q4009, DATA.Q4005, DATA.Q4010];
EstimOpt.NamesMea = {'Q1', 'Q6', 'Q7', 'Q2', 'Q3', 'Q8', 'Q4', 'Q9', 'Q5', 'Q10'};

EstimOpt.NamesLV = {'Extraversion', 'Agreeableness', 'Conscientiousness','Neuroticism','Openness to Experiences'};


%% ****************************  specifying input ****************************


DATA.filter = ones(size(DATA.Y))==1;

INPUT.Y = DATA.Y(DATA.filter); %(~(DATA.Q23 == 2));%(~(DATA.Design == 1 & DATA.ChT10_Q33==2)); %(DATA.CT == 1); %DATA.liczba_alt == 2); 
INPUT.Xa = DATA.X(DATA.filter,:); %(~(DATA.Q23 == 2),:);%(~(DATA.Design == 1 & DATA.ChT10_Q33==2),:); %(DATA.CT == 1,:); %(DATA.liczba_alt == 2,:); 
INPUT.Xmea = DATA.Xmea(DATA.filter,:);


% % INPUT.MissingInd = DATA.Missing(DATA.filter,:); 
MissingCompleteInd = MissingCompleteInd>0;
INPUT.MissingInd = MissingCompleteInd(DATA.filter,:); 
INPUT.MissingInd(any(isnan(INPUT.Xmea),2)) = 1;


%% ****************************  sample characteristics ****************************


EstimOpt.NCT = 12; % Number of choice tasks per person 
EstimOpt.NAlt = 3; % Number of alternatives
EstimOpt.NP = length(INPUT.Y)/EstimOpt.NCT/EstimOpt.NAlt; % numel(unique(DATA.nr))


%% **************************** estimation and optimization options ****************************

% EstimOpt.eps = 1.e-6; % overall precision level

[INPUT, Results, EstimOpt, OptimOpt] = DataCleanDCE(INPUT,EstimOpt);

EstimOpt.NRep = 1e2; % number of draws for numerical simulation
% OptimOpt.MaxIter = 1; % maximum number of iterations

% OptimOpt.Algorithm = 'trust-region'; % 'quasi-newton';
% EstimOpt.NumGrad = 1; % 1
% OptimOpt.GradObj = 'off'; % 'off'
% OptimOpt.FinDiffType = 'central'; % 'forward'
% OptimOpt.Hessian = 'user-supplied'; % 'off'
% EstimOpt.HessEstFix = 1; % 0 = use optimization Hessian, 1 = use jacobian-based (BHHH) Hessian, 2 - use high-precision jacobian-based (BHHH) Hessian 3 - use numerical Hessian
% EstimOpt.ApproxHess = 0;

try
    
  EstimOpt.ProjectName = 'WTP-space';


%% ****************************     MNL     ****************************


EstimOpt.WTP_space = 1;

Results.MNL = MNL(INPUT,Results,EstimOpt,OptimOpt);


%% ****************************     MXL     ****************************

EstimOpt.Dist = [1 0 0 0 0 1];

% B_backup = [6.14385354870408;0.0516403900489720;2.79050910174003;0.212801221553350;-1.08447748688321;59.4605851119900;-0.506853800933674;3.23288266366086;-0.185599199928883;1.05305944403404];

% Results.MXL_d = MXL(INPUT,Results,EstimOpt,OptimOpt);

% linear lognormal: 
% Results.MXL_d.bhat = [-4.35876695098319;-0.0727566188579322;0.654905221042583;0.174337164785562;1.44796325103377;3.77397910971331;0.354528492705601;0.752923188694514;0.141296472156282;5.05520508880132];

%% ****************************     HMNL     ****************************

EstimOpt.Dist = [0 0 0 0 1];
EstimOpt.MNLDist = EstimOpt.Dist;

% EstimOpt.Dist = [0 0 0 0 0 0 0 1];
% EstimOpt.MNLDist = EstimOpt.Dist;

% EstimOpt.RealMin = 0;
% EstimOpt.HessEstFix = 0;

EstimOpt.NLatent = 5;

EstimOpt.MeaMatrix = [ 1 1 0 0 0 0 0 0 0 0; ...
                       0 0 1 1 0 0 0 0 0 0; ...
                       0 0 0 0 1 1 0 0 0 0; ...
                       0 0 0 0 0 0 1 1 0 0; ...
                       0 0 0 0 0 0 0 0 1 1];
EstimOpt.MeaSpecMatrix = 2;

% 0 - 1k: 
% Results.HMNL.b0 = [3.42176776126125;0.332835093015037;0.120935573647539;1.00688362189765;1.11420220379532;0.150157944190866;-0.0145611580873382;0.749096312798566;8.42643303621646;-0.129500955540406;-0.372833024807594;-0.506422434354801;-0.685106808773661;-0.465553397613842;-0.610488076369927;0.503527957180048;2.53319388859759;-0.103268055391365;-0.0481883879480757;0.873740178857685;1.29812503487358;0.0974605650409767;0.307593583619372;-0.202706639523861;-2.02177893958802;-0.0962542575115743;-0.0922308007105962;-0.107684605553792;-0.203914061905040;-0.0223149319924654;-0.155925460011945;0.0648617577543380;-2.15067844519074;0.0375336856085060;0.169221101859208;0.911200968000581;1.16978067538130;0.173227469259404;0.0787232838700382;0.244152833452916;5.56514088956699;0.684836464432313;0.915990733911550;0.187737672001811;0.350184283248291;0.0553020907092254;0.0628009428316861;0.205937624586892;0.0525277759697125;-1.79589082428845;-0.608671412313375;-0.932852949059524;-0.899929682047008;-1.02080475195721;-0.295000748143162;-0.0142707405204823;-1.06370816104892;-0.769806020409370;-1.17705630234136;-0.813421761333000;-0.906884001710269;-0.542590037065753;-0.256082971382205;-2.06661105591135;-1.03587125875937;-1.28968046875408;-1.05780401123931;-0.727892400221553;-0.0921363402415584;0.0680796675111169;-0.615850160929220;-0.698616945981141;-1.23931301353761;-1.11601391364541;-0.537082378002350;-0.818443314566320;-1.17018115790327;-2.96080325512322;-0.597487003027032;-0.784176499655110;-0.497804401089715;-0.411796818029317;0.204404497826659;0.861627945901775;0.0477298912052509;-0.412342688169877;-1.06670730624709;-0.717731260627372;-0.608287883402793;-0.861649192335816;-0.465211235966260;-0.911547917215116;-0.642134723483163;-1.17556209595414;-0.766558002246723;-0.570406058075290;-0.563180464564459;0.456104067311413;-1.95182722580021;-0.678057587670034;-0.913169682154379;-0.658479318153985;-0.780756705041097;-0.101023463307570;-0.245171914017918;-1.77689577950966;-0.673909881632575;-0.996993111352287;-0.555284728548045;-0.643217991256475;-0.279575692030857;0.134780107376637;-1.01328394151569;-0.699603414776833;-1.23443137053343;-0.632774453614715;-1.00068809443694;-0.443858046971249];

% (n) constrained 1k: -29726.6026
% B_backup = [3.49027022217993;0.105859017506069;-0.00396843459556498;1.01805942863955;1.15053716558990;0.412022831092672;0.409651153237157;0.617756303656344;-7.70936858550322;0;0;0;0;0;0;-0.514388168247841;-6.87365888920660;0;0;0;0;0;0;0.0894138339938391;1.31211190124865;0;0;0;0;0;0;-0.000862096368449396;0.733075172242617;0;0;0;0;0;0;0.0567883102640521;2.20242973605223;0;0;0;0;0;0;0.0690883607001773;-0.0546043764941313;-1.79565056699484;-0.608486800579254;-0.932901290954759;-0.900094664637726;-1.02085767719691;-0.294792078357675;0.0304493286742471;-1.06408371872500;-0.769417307028943;-1.17696831769524;-0.813084602374022;-0.906153311668403;-0.542252677291492;0.137757303526554;-2.01964244897071;-1.05844230211297;-1.31208553057937;-1.07729650500352;-0.747724563285415;-0.115220042783502;-0.0283942529741015;-0.614971996673347;-0.701920113002232;-1.24247522519028;-1.11816738828413;-0.537965179075949;-0.817175239710414;0.869895374051619;-2.55818519105161;-0.744304004558093;-0.926726846301960;-0.636733069605070;-0.552321345613674;0.0604094529731740;-1.08926166543671;0.0442395669441890;-0.293413520002204;-0.945328879771240;-0.594487766972781;-0.492855413479167;-0.761413433777502;-0.703642615121019;-0.998266789178338;-0.524248272553237;-1.07426366880461;-0.671428991503902;-0.479581635395651;-0.472238241087727;0.844743660100951;-2.31114373091025;-0.537923654479406;-0.759679822917192;-0.489039556535310;-0.605778691768790;0.0814781007206870;-0.527085099463388;-1.94184672613386;-0.589221544603998;-0.908987756179440;-0.465236623749463;-0.552308798327409;-0.182684218546561;0.325995991929786;-1.05898068579063;-0.651732638274862;-1.18877903796406;-0.591717315415473;-0.961969776392449;-0.409604438938442];
% EstimOpt.BActive = ones(size(B_backup));
% EstimOpt.BActive(end-108:end-103) = 0;
% EstimOpt.BActive(end-100:end-95) = 0;
% EstimOpt.BActive(end-92:end-87) = 0;
% EstimOpt.BActive(end-84:end-79) = 0;
% EstimOpt.BActive(end-76:end-71) = 0;
% B_backup = B_backup .* EstimOpt.BActive;

% (n) unconstrained 1k: -29555.6177
% B_backup = [3.33788738535733;0.482729642192612;0.428356328843067;1.05331270807296;1.22148252278830;0.173788726762071;0.0238470269015163;0.664080559183142;-0.448673691476451;0.0108716143511238;0.151903732672867;0.471636257216835;0.721317591823091;0.201304981244760;0.440452265747208;-0.448326386628408;0.543725336144027;0.0522001916296895;0.0122105359769350;-1.09692567895685;-1.46703759442926;-0.162765368668544;-0.219553568973588;-0.0775009888042398;1.06137102856693;0.133221173939341;0.0920298865656360;0.0526811265054084;0.0102776577319812;-0.0122123654430944;0.0622201901345023;0.0100721982947976;2.25047654859015;-0.110818710156518;-0.0107950817188077;-0.122399594113152;0.00737119349789590;-0.114336455500501;-0.101490468525382;0.0767412296310963;10.5213387096626;0.419083652516953;0.532301725296420;-0.0475122238264056;0.0305141675102729;-0.271456708332277;-0.322473152903682;0.326979642119950;-0.0670419036583043;-1.79648896980657;-0.606984837300484;-0.931666564561023;-0.900067107211730;-1.01997657657379;-0.293814948316225;-0.0147692340587620;-1.06388154750222;-0.769707752352186;-1.17642655217476;-0.813167848259557;-0.907392923389847;-0.542832907351484;-0.0360922851158397;-2.00983418181242;-1.05632458913942;-1.31451332031085;-1.08208233264146;-0.756128950029229;-0.125604855519510;0.0800805216865540;-0.616201514051173;-0.699766781043141;-1.24056559299846;-1.11557483835776;-0.534476589096680;-0.813079622734359;1.12992422658662;-2.89773770623385;-0.625586014227887;-0.799825510721342;-0.510928793855152;-0.429308248078551;0.185587422174433;-0.843588612799682;0.0395517692560380;-0.418250058705190;-1.06855473235684;-0.720638746827565;-0.618092974750021;-0.884044997726955;-0.763383090299859;-1.03146700490348;-0.498374437204545;-1.04849277297229;-0.648593356810268;-0.455575355130377;-0.446891823218668;0.759230588494011;-2.20454325697247;-0.575992889972843;-0.799234091344755;-0.534874874369860;-0.654156126339993;0.0335437030522007;-0.181168682187463;-1.75631906428535;-0.685073121906762;-1.01069437980279;-0.568234942497435;-0.655248775944223;-0.293171364387922;0.0831406706065544;-1.00715075087671;-0.705277258257748;-1.23901808327262;-0.636882516600213;-1.00514077679268;-0.450712558021706];

% WTP-space 1k: -29774.2215
% B_backup = [27.7920962740649;0.333898132660084;0.244740238875215;-1.82645795290174;-2.47288734309557;-1.29911893742691;-1.99411633126891;0.318956109675691;-28.1257716624113;-0.682313758483860;-0.901242030468736;2.25435311925379;2.40574870131380;1.54494215422796;1.67007198641649;0.265994239280564;0.388749084285892;0.606437196141335;0.169965520631825;-2.94503976479580;-3.99147896004756;-0.539617649514775;-0.635403182650196;0.0372338562757451;0.799997186473709;0.556687445529497;0.828902535697022;0.386909286191776;0.731419433646529;0.208091317096591;0.134244272371411;-0.0431235875042142;1.09522306695974;-0.132859871790520;0.146607245838295;0.155259112642561;-0.128937436831449;0.261953934377512;0.596978730347560;-0.0370124598931178;-11.6735676289121;1.56119821417113;2.13802192595819;3.80546632756908;5.09064528504862;0.842651769610137;1.26021700349725;0.143754253246465;-0.0404866870995944;-1.79413905187307;-0.609789709933921;-0.933631479628664;-0.900037743695689;-1.02052310101359;-0.295463921393083;0.0361672938540954;-1.06488159617350;-0.768759202427662;-1.17515950037880;-0.812169364502027;-0.907166285038149;-0.543033432660804;0.0281626297028767;-2.00829060117689;-1.05816115957641;-1.31595431356772;-1.08325678403514;-0.757193268213753;-0.125742304949505;0.00732076210852932;-0.614220063882536;-0.702446562503757;-1.24300955076023;-1.11835274347930;-0.538085659537003;-0.817654509660925;-0.898327000529891;-2.59625527072460;-0.708618970608452;-0.898107402580803;-0.623767196507901;-0.542647992088515;0.0696594954347280;1.01565179175488;0.0331415744634944;-0.334486978865542;-0.987885429753484;-0.637045691468550;-0.524376359674965;-0.776199694983132;0.909224332466643;-1.10403224653392;-0.424214094393109;-0.973791034411823;-0.574927589325745;-0.386295029475776;-0.377969708088039;-0.670373520898640;-2.12574855337476;-0.611905982004058;-0.838233875012677;-0.573422985386334;-0.693177856694869;-0.00812332658398323;-0.0175717643072495;-1.73138243504790;-0.697490596683202;-1.02032214461374;-0.581719601318067;-0.676251552766776;-0.312189002858201;-0.0113664503134943;-1.00341214421987;-0.709377902153892;-1.24331450804398;-0.639986960075907;-1.00766901699851;-0.453938339773633];

% WTP-space constrained 1k: -30228.2295
% B_backup = [33.1259603798654;0.122628849170339;-0.202541252057064;1.02614255509452;0.730084812560620;0.397993970735705;0.0292367405473705;0.345748352354357;-34.8429390881919;0;0;0;0;0;0;0.0585915238797045;1.14200824096263;0;0;0;0;0;0;0.188861438959373;-0.0138690960100066;0;0;0;0;0;0;-0.0506679199775098;-0.545419705294292;0;0;0;0;0;0;-0.0197747119107012;-14.0279250242706;0;0;0;0;0;0;0.288642648017847;-0.0271553637982520;-1.79400914070927;-0.609394927025351;-0.933947193809396;-0.901052547703099;-1.02163878714551;-0.295900197047678;0.0426227884432378;-1.06442836981771;-0.768778382317694;-1.17526449137831;-0.811836931896789;-0.906116412135597;-0.542503040541315;0.215762689557626;-2.05488300111186;-1.03139887319600;-1.28926054031356;-1.05927565009739;-0.734705715418653;-0.104351696714012;-0.0938379441256904;-0.617342177140953;-0.696587049359534;-1.23808021819165;-1.11408591961967;-0.534949116174812;-0.816965324266960;-0.957710186207208;-2.68180865681253;-0.695693196321819;-0.874973918793520;-0.587368100561332;-0.504398185417424;0.106255123280158;0.972328052356585;0.0375825188861819;-0.349159416402591;-0.998906912298462;-0.649775079310209;-0.544280416723470;-0.804138603192263;0.752070775994054;-1.02634005439196;-0.503760106882573;-1.05343271741204;-0.650936891346507;-0.459196309853742;-0.448767268612605;-0.805838534045100;-2.25958203886167;-0.550316044424405;-0.776636397573642;-0.512613335308167;-0.629684235141716;0.0594680441845842;-0.242338819728898;-1.77654193254829;-0.676926529827154;-1.00082855068459;-0.556704784032004;-0.644886747149961;-0.281212237716555;0.109114559885398;-1.00865786201834;-0.702916470204769;-1.23667266433213;-0.634595786040898;-1.00274620498455;-0.448549799630154];
% EstimOpt.BActive = ones(size(B_backup));
% EstimOpt.BActive(end-108:end-103) = 0;
% EstimOpt.BActive(end-100:end-95) = 0;
% EstimOpt.BActive(end-92:end-87) = 0;
% EstimOpt.BActive(end-84:end-79) = 0;
% EstimOpt.BActive(end-76:end-71) = 0;
% B_backup = B_backup .* EstimOpt.BActive;

% -29693.1192
% B_backup = [-2.33971988535058;-0.121974021073810;0.612224828622919;0.114365822786512;-3.34549406733786;-4.04144848441899;-0.310464086770368;-0.555030269404951;-0.189826800195817;2.84130078761985;-9.70111614604634;-0.221427887366071;0.493693372082309;0.00364175447056485;3.97434254916826;-5.55001927051295;-0.124239747830053;0.0591088776863736;-0.0569922820984353;2.21651910782879;6.92580871835681;0.162723928913428;-0.0551566410038068;0.0553174088529811;-3.75696686804872;-5.37085151883923;0.0847212827563681;-0.254864416094483;0.0675334837645426;-1.10065206610148;0.0155971551495099;-1.79465803766921;-0.607852267051579;-0.933120000954346;-0.901297661424759;-1.02176513174246;-0.296204702687745;0.119894595298113;-1.06977011806427;-0.762222127065077;-1.16660979561999;-0.805047993174832;-0.901891660041315;-0.536942424445222;0.237920932737443;-2.06488874458842;-1.02093040842491;-1.28510224015154;-1.05411801576207;-0.729298419719928;-0.0998625179326266;-0.193831971187225;-0.627708229766770;-0.682541988395825;-1.22303939191810;-1.10112900176616;-0.522032383827870;-0.803670303727169;-1.13393649250267;-2.91725052326535;-0.626303986520958;-0.794022856778461;-0.507648885173747;-0.423093093404279;0.189997520928383;0.845373558540346;0.0471325130318435;-0.415724109732076;-1.06703594400637;-0.718401466408966;-0.611059260549293;-0.872112105911163;-0.750375437778744;-1.01073582454466;-0.509763078195818;-1.05302287655063;-0.651883674428416;-0.457163358901474;-0.452713245648856;0.733396231213085;-2.18911309405679;-0.595332296253657;-0.813428742126008;-0.544975770570172;-0.665785219852066;0.0213719289466441;0.282303193301041;-1.79609995506322;-0.665256840165962;-0.994590576680456;-0.547713977367209;-0.634319073553993;-0.269693597003557;-0.180703570627659;-1.01809354435600;-0.691233609159309;-1.22361747088018;-0.623813433737594;-0.993923718014552;-0.440777635292084];

% EstimOpt.RealMin = 1;


% B_backup = [6.49345503128674;-0.206768163694090;2.11029653753591;0.325985133551494;-0.661552794561952;43.8311903483287;0.489138760240779;0.845738806401211;-0.195948856588828;-0.0239044508100306;-10.4691520552124;-0.132030058862014;0.851784781752854;0.246241786317351;-1.10375825755270;1.76229770485671;0.0890823565804247;-0.821340138156675;-0.241115676466483;0.283112852757533;0.462188954463261;-0.121670205874880;-0.871365503734079;-0.172936298719068;0.00661652423758842;15.2767202293178;-0.792270725984052;-3.97054475310309;-0.331412298412745;0.682097406022660;2.27829755299395;0.0723377653660577;-0.396507229110689;-0.272036366266787;0.344079804655460;-0.114248187748539;-1.80537430398231;-0.602661406083355;-0.927668616995350;-0.894682651012806;-1.01550333590096;-0.289881147940711;0.0917709687167021;-1.06792616261044;-0.765114031139274;-1.17349592317160;-0.809952547937028;-0.902816964031940;-0.538278513198675;0.454713862976232;-2.20185942366697;-0.965444607323520;-1.22501037261495;-0.995035983282491;-0.667889329722705;-0.0330378040473740;-0.262629886217967;-0.633621360237480;-0.660506089591532;-1.20575525932710;-1.08837669779548;-0.513841381756043;-0.801106410767382;-0.778732374343611;-2.45170604270740;-0.780530584450153;-0.963592539432289;-0.678459039224693;-0.595432446970154;0.0142558394959939;1.24821929496312;0.0414540902746271;-0.216808892595237;-0.860724949279855;-0.514484842130669;-0.410479923907394;-0.673584890168738;-0.0834048666090606;-0.825183586773323;-0.740748334623181;-1.26625646975982;-0.851354528387613;-0.653035294997784;-0.653108059766892;0.141142513388140;-1.79887811711399;-0.774015496682596;-0.999326720835292;-0.741981482595665;-0.862424714798660;-0.179334074251393;-0.588612799979251;-2.00099514363021;-0.549078630107876;-0.874953750193822;-0.436230040572288;-0.529054983857041;-0.162581257290672;0.239788230274283;-1.03435544562308;-0.677200083796134;-1.21318747790032;-0.613948547503319;-0.981930934986757;-0.429430019243359];


% Results.HMNL = HMNL(INPUT,Results,EstimOpt,OptimOpt);


%% ****************************     HMXL     ****************************

% -30030.3753
B_backup = [8.41383766787049;-0.0149983099908423;3.17595588061245;0.460251203239766;-0.832142046801947;55.2033471329101;0.322408032885209;-1.04373500990259;-0.0623173518031651;-0.190131729195190;14.3276560887404;0.348839435180788;-0.198163822589459;-0.390989830080131;1.11832792609007;-0.555622476875198;-0.605632572193420;-3.27114635692410;-0.185201698764656;0.487557994228249;0.405417236285793;-0.0755285185401256;0.445591022633440;0.131415315239871;0.0529343002786644;-1.19150672672990;-0.0668026293555343;0.242442080817015;0.198303302078978;-0.171997019448448;-3.72604156056986;0.331966406098721;1.59514228620617;0.260630712208187;-0.512319339837546;0.139963327612703;-1.80834996168675;-0.599256005752395;-0.923988741641197;-0.891171430718384;-1.01301434916868;-0.287031388486808;-0.125755014842344;-1.07442976873401;-0.761565795364257;-1.17051123345338;-0.805934305454660;-0.898429645697605;-0.534904442722839;0.282713607830673;-2.08671855408568;-1.01700684044202;-1.27537140517478;-1.04701029013766;-0.719399261271050;-0.0865256962618742;-0.0464170466777042;-0.615028092921256;-0.700282186216927;-1.24143678954355;-1.11752657452216;-0.537934817981131;-0.818709082977510;0.838902994054668;-2.52473282058090;-0.748534760207279;-0.934859051912039;-0.649032624507963;-0.565989583207030;0.0450744771841160;-1.17711231075612;0.0375973980639693;-0.249288005100301;-0.896975353695131;-0.547439743557674;-0.442610298872122;-0.702949184453117;0.740978058091195;-1.01702134193595;-0.505375830610259;-1.05676859577299;-0.656574182226084;-0.467793100786786;-0.459813478273499;-0.833829981341646;-2.29510745260068;-0.539001759600763;-0.761928012373834;-0.495888901439329;-0.616781677123048;0.0716566919848685;0.553875633795293;-1.97329466043425;-0.573897498371579;-0.897607882131634;-0.452404776402403;-0.538114757424654;-0.172780842664422;-0.284428925012423;-1.04337396806094;-0.663198756154432;-1.20039014879560;-0.602949710640098;-0.972736083975344;-0.420666141256760];


EstimOpt.RealMin = 0;

Results.HMXL_d = HMXL(INPUT,Results,EstimOpt,OptimOpt);

    sendmail('mik@czaj.org','MATLAB: WNE - done!');
    
catch theErrorInfo
    
    sendmail('mik@czaj.org','MATLAB: WNE - error!',theErrorInfo.message);
    
end
